# OCP Agent API 文档

---

## 一、查询相关

### 1. 查询主机的 OCP Agent 详情
#### 功能说明
获取指定主机上 OCP Agent 的详细信息。

#### 调用说明
- **权限要求**: `HOST_VIEWER`
- **请求路径**: `GET /compute/hosts/{hostId}/agent`

#### 请求参数
| 参数    | 类型   | 必选 | 示例值 | 描述         |
|--------|--------|------|--------|--------------|
| hostId | Long   | 是   | 100    | 主机 ID      |

#### 返回结果
**通用响应结构**:
```json
{
  "successful": Boolean,
  "timestamp": Datetime,
  "duration": Integer,
  "status": Integer,
  "traceId": String,
  "server": String,
  "data": { /* 详情见 HostAgent 数据结构 */ }
}
```

**HostAgent 数据结构**:
```json
{
  "id": Long,
  "version": String,
  "installHome": String,
  "logHome": String,
  "lastAvailableTime": String,
  "hostId": Long,
  "hostInnerIpAddress": String,
  "status": String (STOPPED/STARTED),
  "processes": [HostAgentProcess],
  "createTime": String,
  "updateTime": String
}
```

**HostAgentProcess 数据结构**（全局通用）:
```json
{
  "id": Long,
  "hostId": Long,
  "alias": String,
  "pid": Integer,
  "user": String,
  "startCommand": String,
  "ports": String,
  "elapsedTime": Long,
  "lastActiveTime": String,
  "status": String (STOPPED/STARTED),
  "operable": Boolean,
  "logFilePattern": String,
  "createTime": String,
  "updateTime": String
}
```

#### 示例
- **请求示例**:  
  `GET /api/v2/compute/hosts/20/agent`

- **返回示例**（部分）:
  ```json
  {
    "data": {
      "id": 2000021,
      "version": "3.1.0-1928505",
      "processes": [
        {
          "alias": "ocp_agentd",
          "pid": 6337,
          "status": "STARTED"
        }
      ]
    }
  }
  ```

---

### 2. 查询主机的 OCP Agent 工作进程列表
#### 功能说明
获取指定主机上 OCP Agent 的工作进程列表。

#### 调用说明
- **权限要求**: `HOST_VIEWER`
- **请求路径**: `GET /compute/hosts/{hostId}/agent/processes`

#### 请求参数
| 参数    | 类型   | 必选 | 示例值 | 描述         |
|--------|--------|------|--------|--------------|
| hostId | Long   | 是   | 100    | 主机 ID      |

#### 返回结果
**数据结构**:
```json
{
  "data": {
    "contents": [HostAgentProcess],
    "page": {
      "number": Integer,
      "size": Integer,
      "totalElements": Integer,
      "totalPages": Integer
    }
  },
  "successful": Boolean,
  "timestamp": Datetime,
  ...
}
```

#### 示例
- **请求示例**:  
  `GET /compute/hosts/10/agent/processes?page=1&size=10`

- **返回示例**（部分）:
  ```json
  {
    "data": {
      "contents": [
        {
          "alias": "ocp_agentd",
          "pid": 8724,
          "status": "STARTED"
        }
      ],
      "page": {
        "totalElements": 6
      }
    }
  }
  ```

---

## 二、进程控制（单实例）

### 3. 停止主机的 OCP Agent 基础进程
#### 功能说明
停止指定主机上的 OCP Agent 基础进程。

#### 调用说明
- **权限要求**: `HOST_MANAGER`
- **请求路径**: `POST /compute/hosts/{hostId}/agent/stop`

#### 请求参数
| 参数    | 类型   | 必选 | 示例值 | 描述         |
|--------|--------|------|--------|--------------|
| hostId | Long   | 是   | 100    | 主机 ID      |

#### 返回结果
返回异步任务信息，结构与 `批量停止` 的 `data` 字段一致。

#### 示例
- **请求示例**:  
  `POST /compute/hosts/2/agent/stop`

---

### 4. 重启主机的 OCP Agent 基础进程
#### 功能说明
重启指定主机上的 OCP Agent 基础进程。

#### 调用说明
- **权限要求**: `HOST_MANAGER`
- **请求路径**: `POST /compute/hosts/{hostId}/agent/restart`

#### 请求参数
| 参数    | 类型   | 必选 | 示例值 | 描述         |
|--------|--------|------|--------|--------------|
| hostId | Long   | 是   | 100    | 主机 ID      |

#### 返回结果
返回异步任务信息，结构与 `批量重启` 的 `data` 字段一致。

#### 示例
- **请求示例**:  
  `POST /compute/hosts/2/agent/restart`

---

### 5. 重启主机的 OCP Agent 工作进程
#### 功能说明
重启指定主机上的某个 OCP Agent 工作进程。

#### 调用说明
- **权限要求**: `HOST_MANAGER`
- **请求路径**: `POST /compute/hosts/{hostId}/agent/processes/{agentProcessId}/restart`

#### 请求参数
| 参数            | 类型   | 必选 | 示例值 | 描述               |
|-----------------|--------|------|--------|--------------------|
| hostId         | Long   | 是   | 20     | 主机 ID            |
| agentProcessId | Long   | 是   | 100    | Agent 进程 ID      |

#### 返回结果
返回更新后的 `HostAgentProcess` 实例。

#### 示例
- **请求示例**:  
  `POST /compute/hosts/20/agent/processes/100/restart`

---

### 6. 停止主机的 OCP Agent 工作进程
#### 功能说明
停止指定主机上的某个 OCP Agent 工作进程。

#### 调用说明
- **权限要求**: `HOST_MANAGER`
- **请求路径**: `POST /compute/hosts/{hostId}/agent/processes/{agentProcessId}/stop`

#### 请求参数
| 参数            | 类型   | 必选 | 示例值 | 描述               |
|-----------------|--------|------|--------|--------------------|
| hostId         | Long   | 是   | 20     | 主机 ID            |
| agentProcessId | Long   | 是   | 100    | Agent 进程 ID      |

#### 返回结果
返回更新后的 `HostAgentProcess` 实例。

#### 示例
- **请求示例**:  
  `POST /compute/hosts/20/agent/processes/100/stop`

---

## 三、批量进程控制

### 7. 批量停止主机的 OCP Agent 基础进程
#### 功能说明
批量停止多个主机的 OCP Agent 基础进程。

#### 调用说明
- **权限要求**: `HOST_MANAGER`
- **请求路径**: `POST /compute/hosts/batchStopAgents`

#### 请求参数
| 参数    | 类型       | 必选 | 示例值         | 描述         |
|--------|------------|------|----------------|--------------|
| hostIds| LongArray  | 是   | [1001, 1002]   | 主机 ID 列表 |

#### 返回结果
返回异步任务信息，包含子任务状态。

#### 示例
- **请求示例**:  
  ```json
  POST /compute/hosts/batchStopAgents
  {
    "hostIds": [2]
  }
  ```

---

### 8. 批量重启主机的 OCP Agent 基础进程
#### 功能说明
批量重启多个主机的 OCP Agent 基础进程。

#### 调用说明
- **权限要求**: `HOST_MANAGER`
- **请求路径**: `POST /compute/hosts/batchRestartAgents`

#### 请求参数
| 参数    | 类型       | 必选 | 示例值         | 描述         |
|--------|------------|------|----------------|--------------|
| hostIds| LongArray  | 是   | [1001, 1002]   | 主机 ID 列表 |

#### 返回结果
返回异步任务信息，包含子任务状态。

#### 示例
- **请求示例**:  
  ```json
  POST /compute/hosts/batchRestartAgents
  {
    "hostIds": [2]
  }
  ```
