# OCP API 文档

---

## 一、OCP 应用信息管理

### 1. 查询 OCP 应用基本信息
#### 功能说明
获取 OCP 应用的元数据信息，包括构建版本、时间、Java 版本等。

#### 接口约束
- 需通过 OCP 应用服务鉴权。

#### 请求路径
`GET /api/v2/info`

#### 请求参数
无。

#### 返回结果
| 参数               | 类型        | 说明                     |
|--------------------|-------------|--------------------------|
| name               | String      | 应用服务名称             |
| group              | Array       | Maven 构建分组名         |
| artifact           | Object      | 构建的制品名             |
| buildTime          | Datetime    | 构建时间                 |
| buildVersion       | String      | 构建版本号               |
| buildJavaVersion   | String      | 构建使用的 Java 版本     |
| springBootVersion  | String      | 构建使用的 Spring Boot 版本 |

#### 示例
**请求示例**  
```code
GET /api/v2/info
```

**返回示例**  
```code
{
    "artifact": "ocp-server",
    "buildVersion": "2.5.0-SNAPSHOT",
    "buildJavaVersion": "1.8",
    "buildTime": "2020-11-29T05:43:31.644+08:00",
    "name": "ocp-server",
    "springBootVersion": "2.2.5.RELEASE",
    "group": "com.oceanbase"
}
```

---

### 2. 查询 OCP 应用状态
#### 功能说明
检查 OCP 应用各模块的健康状态，返回整体健康状态及可选的异常模块名称。

#### 接口约束
- 需通过 OCP 应用服务鉴权。

#### 请求路径
`GET /api/status`

#### 请求参数
| 参数                     | 类型      | 必选 | 示例值 | 描述                                                                 |
|--------------------------|-----------|------|--------|----------------------------------------------------------------------|
| includeUnavailableComponent | Boolean | 否   | true  | 是否返回不可用模块名称。默认 `false`，仅返回状态；设为 `true` 时返回异常模块名。 |

#### 返回结果
- **返回格式**：纯文本。
- **状态值**：
  - `okay`：应用健康（默认可用状态关键字）。
  - `bad`：应用不健康（默认不可用状态关键字）。
- **扩展说明**：  
  状态关键字可通过 OCP 系统参数配置：
  - `ocp.health-check.status.available-keyword`：可用状态关键字。
  - `ocp.health-check.status.unavailable-keyword`：不可用状态关键字。

#### 示例
**请求示例**  
```code
GET /api/status?includeUnavailableComponent=true
```

**返回示例**  
```code
# 应用健康时
okay

# 应用不健康时
bad

# 应用不健康且请求异常模块名时
bad monitordb
```

---

## 二、OCP 系统时间

### 1. 查询 OCP 服务端时间
#### 功能说明
获取 OCP 服务端当前时间，用于验证服务端与本地时间同步。

#### 接口约束
- 无需鉴权，可直接调用。

#### 请求路径
`GET /api/v2/time`

#### 请求参数
无。

#### 返回结果
返回服务端当前时间的 ISO 8601 格式文本。

#### 示例
**请求示例**  
```code
GET /api/v2/time
```

**返回示例**  
```code
2020-11-11T15:46:27.316+08:00
```

---

## 注意事项
1. **路径版本差异**：  
   - `/api/v2/info` 和 `/api/v2/time` 属于 v2 版本接口，而 `/api/status` 未指定版本号，可能存在版本兼容性差异，需注意调用路径的一致性。
2. **返回值配置风险**：  
   `/api/status` 的返回关键字可通过系统参数修改，调用方需确保配置一致性，避免因关键字变更导致解析错误。