# 软件包管理 API 文档

## 1. 查询软件包列表

### 功能说明
通过指定过滤条件查询OCP管理的软件包列表，支持通过名称、类型、版本、操作系统、架构等参数筛选，并支持分页和排序。

### 接口约束
- 需具备 `PACKAGE_VIEWER` 权限

### 请求路径
```http
GET /api/v2/software-packages
```

### 请求参数

| 参数                | 类型            | 必选 | 示例值                          | 描述                                                                 |
|---------------------|-----------------|------|---------------------------------|----------------------------------------------------------------------|
| `keyword`           | String          | 否   | `agent`                         | 按软件包名称关键字过滤                                               |
| `type`              | StringArray     | 否   | `OB_SERVER_INSTALL_PACKAGE`     | 过滤软件包类型（支持多选）<br>可选值：<br> - `OB_SERVER_INSTALL_PACKAGE`<br> - `OCP_AGENT_INSTALL_PACKAGE`<br> - `OBPROXY_INSTALL_PACKAGE`<br> - `OB_BACKUP_AGENT_INSTALL_PACKAGE` |
| `version`           | StringArray     | 否   | `3.1.0`                         | 按版本过滤（支持多选）                                              |
| `operatingSystem`   | StringArray     | 否   | `alios`                         | 按操作系统类型过滤（支持多选）                                      |
| `architecture`      | StringArray     | 否   | `x86_64`                        | 按系统架构过滤（支持多选）                                          |
| `page`              | Integer         | 否   | `1`                             | 分页页码，默认值 `1`                                               |
| `size`              | Integer         | 否   | `10`                            | 每页大小，默认值 `10`，最大 `2000`                                 |
| `sort`              | String          | 否   | `name,asc`                      | 排序规则（格式：`字段,asc/desc`）                                   |

### 返回结果

```json
{
  "data": {
    "contents": [SoftwarePackageMeta],
    "page": {
      "number": Integer,
      "size": Integer,
      "totalElements": Integer,
      "totalPages": Integer
    }
  },
  "successful": Boolean,
  "timestamp": Datetime,
  "duration": Integer,
  "status": Integer,
  "traceId": String,
  "server": String
}
```

### 示例
#### 请求示例
```http
GET /api/v2/software-packages?page=1&size=10&type=OCP_AGENT_INSTALL_PACKAGE
```

#### 返回示例
```json
{
  "data": {
    "contents": [
      {
        "id": 12,
        "name": "t-oceanbase-ocp-agent",
        "fileName": "t-oceanbase-ocp-agent-2.4.2-1898294.alios7.x86_64.rpm",
        "type": "OCP_AGENT_INSTALL_PACKAGE",
        "version": "2.4.2",
        "operatingSystem": "alios7",
        "architecture": "x86_64",
        "size": 31017340,
        "sha1": "e3277366579eac7ecf7a5b6313f2807229567a12",
        "downloadUrl": "http://xxx.xxx.xxx.xxx:8080/api/v2/files/sys-package/t-oceanbase-ocp-agent-2.4.2-1898294.alios7.x86_64.rpm",
        "deletable": true
      }
    ],
    "page": {
      "number": 1,
      "size": 10,
      "totalElements": 2,
      "totalPages": 1
    }
  },
  "successful": true,
  "status": 200
}
```

---

## 2. 上传软件包

### 功能说明
将本地软件包文件上传到OCP服务器。

### 接口约束
- 需具备 `PACKAGE_MANAGER` 权限

### 请求路径
```http
POST /api/v2/software-packages
```

### 请求类型
```http
multipart/form-data
```

### 请求参数

| 参数 | 类型     | 必选 | 示例值 | 描述       |
|------|----------|------|--------|------------|
| `file` | Binary  | 是   | 文件   | 要上传的文件 |

### 返回结果

```json
{
  "data": SoftwarePackageMeta,
  "successful": Boolean,
  "timestamp": Datetime,
  "duration": Integer,
  "status": Integer,
  "traceId": String,
  "server": String
}
```

### 示例
#### 请求示例（修正后）
```http
POST /api/v2/software-packages
Content-Type: multipart/form-data

文件流（文件字段名为 `file`）
```

#### 返回示例
```json
{
  "data": {
    "id": 26,
    "name": "t-oceanbase-ocp-agent",
    "fileName": "t-oceanbase-ocp-agent-3.1.2-20210812221645.alios7.x86_64.rpm",
    "type": "OCP_AGENT_INSTALL_PACKAGE",
    "version": "3.1.2",
    "operatingSystem": "alios7",
    "architecture": "x86_64",
    "size": 38400132,
    "sha1": "4e5ac896c41c7aa9eda09f4a9b72cbe6f7fc78bc",
    "downloadUrl": "http://localhost:8080/api/v2/files/sys-package/t-oceanbase-ocp-agent-3.1.2-20210812221645.alios7.x86_64.rpm"
  },
  "successful": true,
  "status": 200
}
```

---

## 3. 删除软件包

### 功能说明
根据软件包ID删除指定软件包。

### 接口约束
- 需具备 `PACKAGE_MANAGER` 权限

### 请求路径
```http
DELETE /api/v2/software-packages/{id}
```

### 请求参数

| 参数 | 类型     | 必选 | 示例值 | 描述       |
|------|----------|------|--------|------------|
| `id` | Integer  | 是   | `1`    | 软件包唯一ID |

### 返回结果

```json
{
  "successful": Boolean,
  "timestamp": Datetime,
  "duration": Integer,
  "status": Integer,
  "traceId": String,
  "server": String
}
```

### 示例
#### 请求示例
```http
DELETE /api/v2/software-packages/1
```

#### 返回示例
```json
{
  "successful": true,
  "status": 200
}
```

---

## 数据结构

### SoftwarePackageMeta
描述软件包的元数据信息。

| 参数                | 类型     | 描述                                                                 |
|---------------------|----------|----------------------------------------------------------------------|
| `id`                | Integer  | 软件包唯一标识符                                                    |
| `name`              | String   | 软件包名称                                                          |
| `fileName`          | String   | 文件完整名称                                                        |
| `extension`         | String   | 文件扩展名（如 `rpm`）                                              |
| `size`              | Integer  | 文件大小（字节）                                                    |
| `sha1`              | String   | 文件的SHA1哈希值                                                    |
| `downloadUrl`       | String   | 文件下载地址                                                        |
| `type`              | String   | 软件包类型（如 `OCP_AGENT_INSTALL_PACKAGE`）                         |
| `version`           | String   | 版本号                                                              |
| `buildNumber`       | String   | 编译版本号                                                          |
| `operatingSystem`   | String   | 支持的操作系统（如 `alios7`）                                       |
| `architecture`      | String   | 系统架构（如 `x86_64`）                                             |
| `deletable`         | Boolean  | 是否可删除                                                          |

