# OBProxy API 文档

## 1. 集群管理

### 1.1 创建 OBProxy 集群
**功能**：创建 OBProxy 集群  
**约束**：需通过 OCP 鉴权  
**路径**：`POST /api/v2/obproxy/clusters`  

#### 请求参数
| 参数                  | 类型           | 必选 | 示例值                                                                 | 描述                                                                 |
|-----------------------|----------------|------|-------------------------------------------------------------------------|----------------------------------------------------------------------|
| name                 | String         | 是   | "OBProxy001"                                                           | OBProxy 集群名                                                       |
| address              | String         | 否   | "foo.bar"                                                              | 集群访问地址                                                         |
| port                 | Integer        | 否   | 2883                                                                    | 集群访问端口                                                         |
| workMode             | String         | 否   | "CONFIG_URL"                                                           | 工作模式（CONFIG_URL/RS_LIST）                                       |
| obproxyInstallParam  | Object         | 否   | `{ hostIds: [1,2], sqlPort: 2883, exporterPort: 2884, version: "obproxy-1.9.1.1-1919579.el7.x86_64.rpm" }` | 安装参数                                                             |
| ├─ hostIds           | Array<Long>    | 是   | `[1,2]`                                                                 | 安装主机 ID 列表                                                     |
| ├─ sqlPort           | Integer        | 是   | 2883                                                                    | SQL 端口                                                             |
| ├─ exporterPort      | Integer        | 是   | 2884                                                                    | exporter 端口                                                        |
| ├─ version           | String         | 是   | "obproxy-1.9.1.1-1919579.el7.x86_64.rpm"                                 | 软件包版本                                                           |
| obLinks              | Array<ObLink>  | 是   | `[ { clusterName: "hooray", obClusterId: 1, username: "proxyro" } ]`    | 可连接的 OB 集群信息                                                 |
| startupParameters    | Array<Param>   | 是   | `[]`                                                                    | 启动参数（ObproxyParameter 结构）                                   |
| parameters           | Array<Param>   | 是   | `[]`                                                                    | 非启动参数（ObproxyParameter 结构）                                 |

**ObLink 结构**：
| 参数          | 类型    | 必选 | 示例值       | 描述               |
|---------------|---------|------|--------------|--------------------|
| clusterName   | String  | 是   | "hooray"     | OB 集群名          |
| obClusterId   | Integer | 是   | 1            | OB 集群 ID         |
| username      | String  | 是   | "proxyro"    | 连接用户名         |

**ObproxyParameter 结构**：
| 参数 | 类型    | 必选 | 示例值 | 描述      |
|------|---------|------|--------|-----------|
| name | String  | 是   | "foo"  | 参数名    |
| value| String  | 是   | "bar"  | 参数值    |

#### 返回结果
基础数据结构，包含异步任务信息（参见 `任务信息` 文档）。

---

### 1.2 查询 OBProxy 集群列表
**功能**：获取集群列表  
**约束**：需通过 OCP 鉴权  
**路径**：`GET /api/v2/obproxy/clusters`  

#### 返回结果
| 参数       | 类型       | 描述                                                                 |
|------------|------------|----------------------------------------------------------------------|
| data       | Object     | 包含 `contents`（集群数组）和 `page`（分页信息）                     |
| page       | Object     | 分页信息（totalElements、totalPage、number、size）                   |

**集群数据结构**（`ObproxyCluster`）：
| 参数                | 类型             | 描述                                                                 |
|---------------------|------------------|----------------------------------------------------------------------|
| id                 | Long            | 集群 ID                                                             |
| name               | String          | 集群名称                                                            |
| address            | String          | 访问地址                                                            |
| port               | Integer         | 访问端口                                                            |
| obLinks            | Array<ObLink>   | 可连接的 OB 集群列表                                               |
| versions           | Array<VersionStatInfo> | 版本统计信息（版本号和数量）                                |

**分页数据结构**：
| 参数          | 类型    | 描述          |
|---------------|---------|---------------|
| totalElements | Integer | 总记录数      |
| totalPage     | Integer | 总页数        |
| number        | Integer | 当前页码      |
| size          | Integer | 每页大小      |

---

### 1.3 更新 OBProxy 集群配置
**功能**：更新集群配置  
**约束**：需通过 OCP 鉴权  
**路径**：`PATCH /api/v2/obproxy/clusters/{id}`  

#### 请求参数
| 参数   | 类型    | 必选 | 示例值 | 描述               |
|--------|---------|------|--------|--------------------|
| id     | Long    | 是   | 1      | 集群 ID            |
| body   | Object  |      |        | 需更新的字段（address、port） |

**示例请求体**：
```json
{
  "address": "new.foo.bar",
  "port": 2884
}
```

#### 返回结果
基础数据结构，包含更新后的集群信息（同 `ObproxyCluster` 结构）。

---

### 1.4 删除 OBProxy 集群
**功能**：删除集群  
**约束**：需通过 OCP 鉴权  
**路径**：`DELETE /api/v2/obproxy/clusters/{id}`  

#### 请求参数
| 参数 | 类型  | 必选 | 示例值 | 描述       |
|------|-------|------|--------|------------|
| id   | Long  | 是   | 1      | 集群 ID    |

#### 返回结果
基础数据结构，包含异步任务信息。

---

## 2. OBProxy 实例管理

### 2.1 添加 OBProxy 实例
**功能**：向集群添加 OBProxy 实例  
**约束**：需通过 OCP 鉴权  
**路径**：`POST /api/v2/obproxy/clusters/{id}/obproxies/batchAdd`  

#### 请求参数
| 参数          | 类型           | 必选 | 示例值                                                                 | 描述                     |
|---------------|----------------|------|-------------------------------------------------------------------------|--------------------------|
| id            | Long           | 是   | 1                                                                      | 集群 ID                  |
| hostIds       | Array<Long>    | 是   | `[2]`                                                                  | 需安装的主机 ID 列表     |
| sqlPort       | Integer        | 是   | 2883                                                                   | SQL 端口                 |
| exporterPort  | Integer        | 是   | 2884                                                                   | exporter 端口            |
| version       | String         | 是   | "obproxy-1.9.1.1-1919579.el7.x86_64.rpm"                              | 软件包版本               |

#### 返回结果
基础数据结构，包含异步任务信息。

---

### 2.2 删除 OBProxy 实例
**功能**：删除集群中的 OBProxy 实例  
**约束**：需通过 OCP 鉴权  
**路径**：`DELETE /api/v2/obproxy/clusters/{id}/obproxies/{obproxyIds}`  

#### 请求参数
| 参数          | 类型      | 必选 | 示例值          | 描述               |
|---------------|-----------|------|-----------------|--------------------|
| id            | Long      | 是   | 1               | 集群 ID            |
| obproxyIds    | Array<Long>| 是   | "2"            | 需删除的实例 ID 列表 |

#### 返回结果
基础数据结构，包含异步任务信息。

---

## 3. 参数管理

### 3.1 查询 OBProxy 参数元数据
**功能**：获取参数的元数据信息  
**约束**：需通过 OCP 鉴权  
**路径**：`GET /api/v2/obproxy/parameterInfo`  

#### 请求参数
| 参数       | 类型    | 必选 | 示例值          | 描述               |
|------------|---------|------|-----------------|--------------------|
| name       | String  | 否   | "create_conn_cont_num" | 参数名过滤      |
| version    | String  | 否   | "2.1.0"         | 版本号过滤        |

#### 返回结果
| 参数               | 类型    | 描述                                                                 |
|--------------------|---------|----------------------------------------------------------------------|
| data               | Array   | ParameterInfo 数组                                                   |

**ParameterInfo 结构**：
| 参数                | 类型    | 描述                                                                 |
|---------------------|---------|----------------------------------------------------------------------|
| name               | String  | 参数名                                                              |
| version            | String  | 对应的 OBProxy 版本                                                 |
| type               | String  | 参数类型（INT/STRING/BOOL/TIME 等）                                 |
| allowedStringValues| String  | 允许的字符串值（如 "[0,100]"）                                     |

---

### 3.2 查询集群参数设置
**功能**：获取集群的参数配置  
**约束**：需通过 OCP 鉴权  
**路径**：`GET /api/v2/obproxy/clusters/{id}/parameters`  

#### 请求参数
| 参数 | 类型  | 必选 | 示例值 | 描述       |
|------|-------|------|--------|------------|
| id   | Long  | 是   | 1      | 集群 ID    |

#### 返回结果
| 参数                | 类型                | 描述                                                                 |
|---------------------|---------------------|----------------------------------------------------------------------|
| data               | Array<ObproxyClusterParameter> | 参数列表                                                         |

**ObproxyClusterParameter 结构**：
| 参数                | 类型             | 描述                                                                 |
|---------------------|------------------|----------------------------------------------------------------------|
| name               | String          | 参数名                                                              |
| values             | Array<ObproxyParameterValue> | 不同实例的参数值                                              |

---

## 4. 高级操作

### 4.1 接管 OBProxy 实例
**功能**：将 OBProxy 实例接管到集群  
**约束**：需通过 OCP 鉴权  
**路径**：`POST /api/v2/obproxy/clusters/{id}/takeOver`  

#### 请求参数
| 参数   | 类型           | 必选 | 示例值                                                                 | 描述                     |
|--------|----------------|------|-------------------------------------------------------------------------|--------------------------|
| id     | Long           | 是   | 1                                                                      | 集群 ID                  |
| hosts  | Array<ObproxyTakeOverParam> | 是   | `[ { hostId: 1, sqlPort: 2883 } ]` | 需接管的主机和端口信息 |

**ObproxyTakeOverParam 结构**：
| 参数       | 类型      | 必选 | 示例值 | 描述               |
|------------|-----------|------|--------|--------------------|
| hostId    | Long      | 是   | 1      | 主机 ID            |
| sqlPort   | Integer   | 是   | 2883   | OBProxy 的 SQL 端口 |

#### 返回结果
基础数据结构，包含异步任务信息。

---

### 4.2 升级 OBProxy
**功能**：升级指定实例  
**约束**：需通过 OCP 鉴权  
**路径**：`POST /api/v2/obproxy/clusters/{id}/obproxies/{obproxyIds}/upgrade`  

#### 请求参数
| 参数          | 类型      | 必选 | 示例值          | 描述               |
|---------------|-----------|------|-----------------|--------------------|
| id            | Long      | 是   | 1               | 集群 ID            |
| obproxyIds    | Array<Long>| 是   | "2"            | 需升级的实例 ID    |
| shortRpmName  | String    | 是   | "obproxy-1.9.1.1-1919579" | 升级包名称     |

#### 返回结果
基础数据结构，包含异步任务信息。

---

## 5. 其他操作

### 5.1 重启 OBProxy
**功能**：重启指定实例  
**约束**：需通过 OCP 鉴权  
**路径**：`POST /api/v2/obproxy/clusters/{id}/obproxies/{obproxyIds}/restart`  

#### 请求参数
| 参数          | 类型      | 必选 | 示例值          | 描述               |
|---------------|-----------|------|-----------------|--------------------|
| id            | Long      | 是   | 1               | 集群 ID            |
| obproxyIds    | Array<Long>| 是   | "2"            | 需重启的实例 ID    |

#### 返回结果
基础数据结构，包含异步任务信息。

---

### 5.2 添加/删除可连接 OB 集群
**功能**：管理 OBProxy 可连接的 OB 集群  
**添加**：  
**路径**：`POST /api/v2/obproxy/clusters/{id}/obLinks/batchAdd`  
**删除**：  
**路径**：`DELETE /api/v2/obproxy/clusters/{id}/obLinks/{obClusterName}`  

#### 请求参数（添加）
| 参数          | 类型           | 必选 | 示例值                                                                 | 描述                     |
|---------------|----------------|------|-------------------------------------------------------------------------|--------------------------|
| id            | Long           | 是   | 1                                                                      | 集群 ID                  |
| body          | Array<ObLink>  | 是   | `[ { clusterName: "obcluster", obClusterId: 1, username: "proxyro" } ]` | OB 集群信息              |

#### 请求参数（删除）
| 参数                | 类型    | 必选 | 示例值          | 描述               |
|---------------------|---------|------|-----------------|--------------------|
| id                 | Long    | 是   | 1               | 集群 ID            |
| obClusterName      | String  | 是   | "obcluster"     | 需删除的 OB 集群名 |

---

## 附录

### 附录 1：任务信息结构
任务信息通过 `data` 字段返回，包含以下关键字段：
- `id`: 任务 ID
- `status`: 当前状态（如 "RUNNING"）
- `subtasks`: 子任务列表（包含执行细节如 `className`, `description`, `status` 等）

### 附录 2：状态码说明
- `200`: 成功
- `401`: 未授权
- `404`: 资源不存在

（注：具体状态码需参考实际接口定义）
